@@ -177,7 +177,12 @@ def prepare_data_pipeline_matrix(pipelines, enet_alpha=0.001, enet_l1=0.1):
     }
     return data
 
-
+def get_pipeline_profiler_html(pipelines):
+    id = id_generator()
+    data_dict = prepare_data_pipeline_matrix(pipelines)
+    html_all = make_html(data_dict, id)
+    return html_all
+    
 def plot_pipeline_matrix(pipelines):
     from IPython.core.display import display, HTML
     id = id_generator()
